==> jPod-5.3-sources.jar: de/intarsys/pdf/app/appearance/AppearanceCreatorTools.java <==
/*
 * Copyright (c) 2007, intarsys consulting GmbH
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * - Redistributions of source code must retain the above copyright notice,
 *   this list of conditions and the following disclaimer.
 *
 * - Redistributions in binary form must reproduce the above copyright notice,
 *   this list of conditions and the following disclaimer in the documentation
 *   and/or other materials provided with the distribution.
 *
 * - Neither the name of intarsys nor the names of its contributors may be used
 *   to endorse or promote products derived from this software without specific
 *   prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
package de.intarsys.pdf.app.appearance;

import java.util.Iterator;

import de.intarsys.pdf.cos.COSName;
import de.intarsys.pdf.pd.PDAcroFormField;
import de.intarsys.pdf.pd.PDAnnotation;
import de.intarsys.pdf.pd.PDAppearance;
import de.intarsys.pdf.pd.PDObject;
import de.intarsys.tools.attribute.Attribute;

/**
 * Tool class for tasks related to appearance creation.
 */
public class AppearanceCreatorTools {

	private static final Attribute ATTR_APPEARANCECREATOR = new Attribute(
			"appearanceCreator");

	public static void createAppearance(PDAcroFormField field) {
		IAppearanceCreator appearanceCreator = getAppearanceCreator(field);
		for (Iterator i = field.getAnnotations().iterator(); i.hasNext();) {
			PDAnnotation annot = (PDAnnotation) i.next();
			createAppearance(annot, appearanceCreator);
		}
	}

	static public PDAppearance createAppearance(PDAnnotation annotation) {
		IAppearanceCreator appearanceCreator = getAppearanceCreator(annotation);
		return createAppearance(annotation, appearanceCreator);
	}

	static public PDAppearance createAppearance(PDAnnotation annotation,
			IAppearanceCreator appearanceCreator) {
		if (appearanceCreator == null) {
			COSName type = annotation.cosGetSubtype();
			appearanceCreator = AppearanceCreatorRegistry.get()
					.lookupAppearanceCreator(type);
			if (appearanceCreator == null) {
				appearanceCreator = new NullAppearanceCreator();
			}
		}
		PDAppearance appearance = appearanceCreator.createAppearance(
				annotation, null);
		annotation.setAppearance(appearance);
		return appearance;
	}

	static public IAppearanceCreator getAppearanceCreator(
			PDObject fieldOrAnntotation) {
		return (IAppearanceCreator) fieldOrAnntotation
				.getAttribute(ATTR_APPEARANCECREATOR);
	}

	static public void setAppearanceCreator(PDObject fieldOrAnntotation,
			IAppearanceCreator appearanceCreator) {
		fieldOrAnntotation.setAttribute(ATTR_APPEARANCECREATOR,
				appearanceCreator);
	}
}

==> jPod-5.5.1-sources.jar: de/intarsys/pdf/app/appearance/AppearanceCreatorTools.java <==
/*
 * Copyright (c) 2007, intarsys consulting GmbH
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * - Redistributions of source code must retain the above copyright notice,
 *   this list of conditions and the following disclaimer.
 *
 * - Redistributions in binary form must reproduce the above copyright notice,
 *   this list of conditions and the following disclaimer in the documentation
 *   and/or other materials provided with the distribution.
 *
 * - Neither the name of intarsys nor the names of its contributors may be used
 *   to endorse or promote products derived from this software without specific
 *   prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
package de.intarsys.pdf.app.appearance;

import java.util.Iterator;

import de.intarsys.pdf.cos.COSName;
import de.intarsys.pdf.pd.PDAcroFormField;
import de.intarsys.pdf.pd.PDAnnotation;
import de.intarsys.pdf.pd.PDAppearance;
import de.intarsys.pdf.pd.PDObject;
import de.intarsys.tools.attribute.Attribute;

/**
 * Tool class for tasks related to appearance creation.
 */
public class AppearanceCreatorTools {

	private static final Attribute ATTR_APPEARANCECREATOR = new Attribute(
			"appearanceCreator");

	public static void createAppearance(PDAcroFormField field) {
		IAppearanceCreator appearanceCreator = getAppearanceCreator(field);
		for (Iterator i = field.getLogicalRoot().getAnnotations().iterator(); i
				.hasNext();) {
			PDAnnotation annot = (PDAnnotation) i.next();
			createAppearance(annot, appearanceCreator);
		}
	}

	static public PDAppearance createAppearance(PDAnnotation annotation) {
		IAppearanceCreator appearanceCreator = getAppearanceCreator(annotation);
		return createAppearance(annotation, appearanceCreator);
	}

	static public PDAppearance createAppearance(PDAnnotation annotation,
			IAppearanceCreator appearanceCreator) {
		if (appearanceCreator == null) {
			COSName type = annotation.cosGetSubtype();
			appearanceCreator = AppearanceCreatorRegistry.get()
					.lookupAppearanceCreator(type);
			if (appearanceCreator == null) {
				appearanceCreator = new NullAppearanceCreator();
			}
		}
		PDAppearance appearance = appearanceCreator.createAppearance(
				annotation, null);
		annotation.setAppearance(appearance);
		return appearance;
	}

	static public IAppearanceCreator getAppearanceCreator(
			PDObject fieldOrAnntotation) {
		return (IAppearanceCreator) fieldOrAnntotation
				.getAttribute(ATTR_APPEARANCECREATOR);
	}

	static public void setAppearanceCreator(PDObject fieldOrAnntotation,
			IAppearanceCreator appearanceCreator) {
		fieldOrAnntotation.setAttribute(ATTR_APPEARANCECREATOR,
				appearanceCreator);
	}
}
